import org.openjdk.jmh.annotations.Benchmark;
import org.openjdk.jmh.annotations.OperationsPerInvocation;

import java.util.concurrent.TimeUnit;
import java.util.concurrent.locks.LockSupport;

public class SleepTime {
    private final static int batchSize = 1000;

    @Benchmark
    @OperationsPerInvocation(batchSize)
    public void Thread_yield() {
        for (int i = 0; i < batchSize; i++) {
            Thread.yield();
        }
    }

    @Benchmark
    @OperationsPerInvocation(batchSize)
    public void Thread_onSpinWait() {
        for (int i = 0; i < batchSize; i++) {
            Thread.onSpinWait();
        }
    }

    @Benchmark
    @OperationsPerInvocation(batchSize)
    public void Thread_sleep_0() throws InterruptedException {
        for (int i = 0; i < batchSize; i++) {
            Thread.sleep(0);
        }
    }

    @Benchmark
    @OperationsPerInvocation(batchSize)
    public void Object_wait_0_1() throws InterruptedException {
        synchronized (this) {
            for (int i = 0; i < batchSize; i++) {
                this.wait(0, 1);
            }
        }
    }

    @Benchmark
    @OperationsPerInvocation(batchSize)
    public void LockSupport_parkNanos_1() {
        for (int i = 0; i < batchSize; i++) {
            LockSupport.parkNanos(1);
        }
    }

    @Benchmark
    @OperationsPerInvocation(batchSize)
    public void LockSupport_parkNanos_10() {
        for (int i = 0; i < batchSize; i++) {
            LockSupport.parkNanos(10);
        }
    }

    @Benchmark
    @OperationsPerInvocation(batchSize)
    public void LockSupport_parkNanos_100() {
        for (int i = 0; i < batchSize; i++) {
            LockSupport.parkNanos(100);
        }
    }

    @Benchmark
    @OperationsPerInvocation(batchSize)
    public void LockSupport_parkNanos_1000() {
        for (int i = 0; i < batchSize; i++) {
            LockSupport.parkNanos(1000);
        }
    }

    @Benchmark
    @OperationsPerInvocation(batchSize)
    public void LockSupport_parkNanos_10000() {
        for (int i = 0; i < batchSize; i++) {
            LockSupport.parkNanos(1000);
        }
    }
}